==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/template/CruiseControlTemplateFluent.java <==
package io.strimzi.api.kafka.model.template;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

public interface CruiseControlTemplateFluent<A extends CruiseControlTemplateFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildDeployment instead.
 * @return The buildable object.
 */
@Deprecated public ResourceTemplate getDeployment();
    public ResourceTemplate buildDeployment();
    public A withDeployment(ResourceTemplate deployment);
    public Boolean hasDeployment();
    public CruiseControlTemplateFluent.DeploymentNested<A> withNewDeployment();
    public CruiseControlTemplateFluent.DeploymentNested<A> withNewDeploymentLike(ResourceTemplate item);
    public CruiseControlTemplateFluent.DeploymentNested<A> editDeployment();
    public CruiseControlTemplateFluent.DeploymentNested<A> editOrNewDeployment();
    public CruiseControlTemplateFluent.DeploymentNested<A> editOrNewDeploymentLike(ResourceTemplate item);
    
/**
 * This method has been deprecated, please use method buildPod instead.
 * @return The buildable object.
 */
@Deprecated public PodTemplate getPod();
    public PodTemplate buildPod();
    public A withPod(PodTemplate pod);
    public Boolean hasPod();
    public CruiseControlTemplateFluent.PodNested<A> withNewPod();
    public CruiseControlTemplateFluent.PodNested<A> withNewPodLike(PodTemplate item);
    public CruiseControlTemplateFluent.PodNested<A> editPod();
    public CruiseControlTemplateFluent.PodNested<A> editOrNewPod();
    public CruiseControlTemplateFluent.PodNested<A> editOrNewPodLike(PodTemplate item);
    
/**
 * This method has been deprecated, please use method buildApiService instead.
 * @return The buildable object.
 */
@Deprecated public ResourceTemplate getApiService();
    public ResourceTemplate buildApiService();
    public A withApiService(ResourceTemplate apiService);
    public Boolean hasApiService();
    public CruiseControlTemplateFluent.ApiServiceNested<A> withNewApiService();
    public CruiseControlTemplateFluent.ApiServiceNested<A> withNewApiServiceLike(ResourceTemplate item);
    public CruiseControlTemplateFluent.ApiServiceNested<A> editApiService();
    public CruiseControlTemplateFluent.ApiServiceNested<A> editOrNewApiService();
    public CruiseControlTemplateFluent.ApiServiceNested<A> editOrNewApiServiceLike(ResourceTemplate item);
    
/**
 * This method has been deprecated, please use method buildPodDisruptionBudget instead.
 * @return The buildable object.
 */
@Deprecated public PodDisruptionBudgetTemplate getPodDisruptionBudget();
    public PodDisruptionBudgetTemplate buildPodDisruptionBudget();
    public A withPodDisruptionBudget(PodDisruptionBudgetTemplate podDisruptionBudget);
    public Boolean hasPodDisruptionBudget();
    public CruiseControlTemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudget();
    public CruiseControlTemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    public CruiseControlTemplateFluent.PodDisruptionBudgetNested<A> editPodDisruptionBudget();
    public CruiseControlTemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudget();
    public CruiseControlTemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    
/**
 * This method has been deprecated, please use method buildCruiseControlContainer instead.
 * @return The buildable object.
 */
@Deprecated public ContainerTemplate getCruiseControlContainer();
    public ContainerTemplate buildCruiseControlContainer();
    public A withCruiseControlContainer(ContainerTemplate cruiseControlContainer);
    public Boolean hasCruiseControlContainer();
    public CruiseControlTemplateFluent.CruiseControlContainerNested<A> withNewCruiseControlContainer();
    public CruiseControlTemplateFluent.CruiseControlContainerNested<A> withNewCruiseControlContainerLike(ContainerTemplate item);
    public CruiseControlTemplateFluent.CruiseControlContainerNested<A> editCruiseControlContainer();
    public CruiseControlTemplateFluent.CruiseControlContainerNested<A> editOrNewCruiseControlContainer();
    public CruiseControlTemplateFluent.CruiseControlContainerNested<A> editOrNewCruiseControlContainerLike(ContainerTemplate item);
    
/**
 * This method has been deprecated, please use method buildTlsSidecarContainer instead.
 * @return The buildable object.
 */
@Deprecated public ContainerTemplate getTlsSidecarContainer();
    public ContainerTemplate buildTlsSidecarContainer();
    public A withTlsSidecarContainer(ContainerTemplate tlsSidecarContainer);
    public Boolean hasTlsSidecarContainer();
    public CruiseControlTemplateFluent.TlsSidecarContainerNested<A> withNewTlsSidecarContainer();
    public CruiseControlTemplateFluent.TlsSidecarContainerNested<A> withNewTlsSidecarContainerLike(ContainerTemplate item);
    public CruiseControlTemplateFluent.TlsSidecarContainerNested<A> editTlsSidecarContainer();
    public CruiseControlTemplateFluent.TlsSidecarContainerNested<A> editOrNewTlsSidecarContainer();
    public CruiseControlTemplateFluent.TlsSidecarContainerNested<A> editOrNewTlsSidecarContainerLike(ContainerTemplate item);

    public interface DeploymentNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceTemplateFluent<CruiseControlTemplateFluent.DeploymentNested<N>>{

        
    public N and();    public N endDeployment();
}
    public interface PodNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateFluent<CruiseControlTemplateFluent.PodNested<N>>{

        
    public N and();    public N endPod();
}
    public interface ApiServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceTemplateFluent<CruiseControlTemplateFluent.ApiServiceNested<N>>{

        
    public N and();    public N endApiService();
}
    public interface PodDisruptionBudgetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodDisruptionBudgetTemplateFluent<CruiseControlTemplateFluent.PodDisruptionBudgetNested<N>>{

        
    public N and();    public N endPodDisruptionBudget();
}
    public interface CruiseControlContainerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ContainerTemplateFluent<CruiseControlTemplateFluent.CruiseControlContainerNested<N>>{

        
    public N and();    public N endCruiseControlContainer();
}
    public interface TlsSidecarContainerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ContainerTemplateFluent<CruiseControlTemplateFluent.TlsSidecarContainerNested<N>>{

        
    public N and();    public N endTlsSidecarContainer();
}


}

==> api-0.23.0-sources.jar: io/strimzi/api/kafka/model/template/CruiseControlTemplateFluent.java <==
package io.strimzi.api.kafka.model.template;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

public interface CruiseControlTemplateFluent<A extends CruiseControlTemplateFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildDeployment instead.
 * @return The buildable object.
 */
@Deprecated public ResourceTemplate getDeployment();
    public ResourceTemplate buildDeployment();
    public A withDeployment(ResourceTemplate deployment);
    public Boolean hasDeployment();
    public CruiseControlTemplateFluent.DeploymentNested<A> withNewDeployment();
    public CruiseControlTemplateFluent.DeploymentNested<A> withNewDeploymentLike(ResourceTemplate item);
    public CruiseControlTemplateFluent.DeploymentNested<A> editDeployment();
    public CruiseControlTemplateFluent.DeploymentNested<A> editOrNewDeployment();
    public CruiseControlTemplateFluent.DeploymentNested<A> editOrNewDeploymentLike(ResourceTemplate item);
    
/**
 * This method has been deprecated, please use method buildPod instead.
 * @return The buildable object.
 */
@Deprecated public PodTemplate getPod();
    public PodTemplate buildPod();
    public A withPod(PodTemplate pod);
    public Boolean hasPod();
    public CruiseControlTemplateFluent.PodNested<A> withNewPod();
    public CruiseControlTemplateFluent.PodNested<A> withNewPodLike(PodTemplate item);
    public CruiseControlTemplateFluent.PodNested<A> editPod();
    public CruiseControlTemplateFluent.PodNested<A> editOrNewPod();
    public CruiseControlTemplateFluent.PodNested<A> editOrNewPodLike(PodTemplate item);
    
/**
 * This method has been deprecated, please use method buildApiService instead.
 * @return The buildable object.
 */
@Deprecated public InternalServiceTemplate getApiService();
    public InternalServiceTemplate buildApiService();
    public A withApiService(InternalServiceTemplate apiService);
    public Boolean hasApiService();
    public CruiseControlTemplateFluent.ApiServiceNested<A> withNewApiService();
    public CruiseControlTemplateFluent.ApiServiceNested<A> withNewApiServiceLike(InternalServiceTemplate item);
    public CruiseControlTemplateFluent.ApiServiceNested<A> editApiService();
    public CruiseControlTemplateFluent.ApiServiceNested<A> editOrNewApiService();
    public CruiseControlTemplateFluent.ApiServiceNested<A> editOrNewApiServiceLike(InternalServiceTemplate item);
    
/**
 * This method has been deprecated, please use method buildPodDisruptionBudget instead.
 * @return The buildable object.
 */
@Deprecated public PodDisruptionBudgetTemplate getPodDisruptionBudget();
    public PodDisruptionBudgetTemplate buildPodDisruptionBudget();
    public A withPodDisruptionBudget(PodDisruptionBudgetTemplate podDisruptionBudget);
    public Boolean hasPodDisruptionBudget();
    public CruiseControlTemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudget();
    public CruiseControlTemplateFluent.PodDisruptionBudgetNested<A> withNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    public CruiseControlTemplateFluent.PodDisruptionBudgetNested<A> editPodDisruptionBudget();
    public CruiseControlTemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudget();
    public CruiseControlTemplateFluent.PodDisruptionBudgetNested<A> editOrNewPodDisruptionBudgetLike(PodDisruptionBudgetTemplate item);
    
/**
 * This method has been deprecated, please use method buildCruiseControlContainer instead.
 * @return The buildable object.
 */
@Deprecated public ContainerTemplate getCruiseControlContainer();
    public ContainerTemplate buildCruiseControlContainer();
    public A withCruiseControlContainer(ContainerTemplate cruiseControlContainer);
    public Boolean hasCruiseControlContainer();
    public CruiseControlTemplateFluent.CruiseControlContainerNested<A> withNewCruiseControlContainer();
    public CruiseControlTemplateFluent.CruiseControlContainerNested<A> withNewCruiseControlContainerLike(ContainerTemplate item);
    public CruiseControlTemplateFluent.CruiseControlContainerNested<A> editCruiseControlContainer();
    public CruiseControlTemplateFluent.CruiseControlContainerNested<A> editOrNewCruiseControlContainer();
    public CruiseControlTemplateFluent.CruiseControlContainerNested<A> editOrNewCruiseControlContainerLike(ContainerTemplate item);
    
/**
 * This method has been deprecated, please use method buildTlsSidecarContainer instead.
 * @return The buildable object.
 */
@Deprecated public ContainerTemplate getTlsSidecarContainer();
    public ContainerTemplate buildTlsSidecarContainer();
    public A withTlsSidecarContainer(ContainerTemplate tlsSidecarContainer);
    public Boolean hasTlsSidecarContainer();
    public CruiseControlTemplateFluent.TlsSidecarContainerNested<A> withNewTlsSidecarContainer();
    public CruiseControlTemplateFluent.TlsSidecarContainerNested<A> withNewTlsSidecarContainerLike(ContainerTemplate item);
    public CruiseControlTemplateFluent.TlsSidecarContainerNested<A> editTlsSidecarContainer();
    public CruiseControlTemplateFluent.TlsSidecarContainerNested<A> editOrNewTlsSidecarContainer();
    public CruiseControlTemplateFluent.TlsSidecarContainerNested<A> editOrNewTlsSidecarContainerLike(ContainerTemplate item);
    public interface DeploymentNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ResourceTemplateFluent<CruiseControlTemplateFluent.DeploymentNested<N>> {

            public N and();
            public N endDeployment();    }


    public interface PodNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodTemplateFluent<CruiseControlTemplateFluent.PodNested<N>> {

            public N and();
            public N endPod();    }


    public interface ApiServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,InternalServiceTemplateFluent<CruiseControlTemplateFluent.ApiServiceNested<N>> {

            public N and();
            public N endApiService();    }


    public interface PodDisruptionBudgetNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,PodDisruptionBudgetTemplateFluent<CruiseControlTemplateFluent.PodDisruptionBudgetNested<N>> {

            public N and();
            public N endPodDisruptionBudget();    }


    public interface CruiseControlContainerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ContainerTemplateFluent<CruiseControlTemplateFluent.CruiseControlContainerNested<N>> {

            public N and();
            public N endCruiseControlContainer();    }


    public interface TlsSidecarContainerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ContainerTemplateFluent<CruiseControlTemplateFluent.TlsSidecarContainerNested<N>> {

            public N and();
            public N endTlsSidecarContainer();    }


}
